@@ -21,8 +21,6 @@ use std::io::{stdin, stdout, Read, Write};
 use tracing::debug;
 use xor_name::XorName;
 
-const UNKNOWN_PUBLIC_NAME: &str = "<unknown>";
-
 // Warn the user about a dry-run being performed
 pub fn notice_dry_run() {
     println!("NOTE the operation is being performed in dry-run mode, therefore no changes are committed to the network.");
@@ -182,25 +180,12 @@ where
     }
 }
 
-// Pretty print an NRS Map
-pub fn print_nrs_map(nrs_map: &NrsMap, public_name: &Option<String>) {
-    let mut table = Table::new();
-    table.add_row(row![bFg->"NRS name/subname", bFg->"Created", bFg->"Modified", bFg->"Link"]);
-
+pub fn print_nrs_map(nrs_map: &NrsMap) {
+    println!("Listing NRS map contents:");
     let summary = nrs_map.get_map_summary();
-    let pub_name: &str = match public_name {
-        Some(name) => name,
-        None => UNKNOWN_PUBLIC_NAME,
-    };
-    summary.iter().for_each(|(name, rdf_info)| {
-        table.add_row(row![
-            format!("{}{}", name, pub_name),
-            rdf_info["created"],
-            rdf_info["modified"],
-            rdf_info["link"],
-        ]);
+    summary.iter().for_each(|(pub_name, link)| {
+        println!("{}: {}", pub_name, link);
     });
-    table.printstd();
 }
 
 // returns singular or plural version of string, based on count.
